R/plot_ml.R
plotDrugDist.Rd
Reads metadata and generates a stacked bar plot showing counts of resistant and susceptible phenotypes per antibiotic.
plotDrugDist(metadata_path = ".")
Character. Path to directory containing metadata.parquet.
metadata.parquet
A ggplot object.
plotDrugDist(metadata_path = system.file("extdata", package = "amRml"))