Generates a plot showing the top features and their variable importance scores.

plotTopFeatsVI(fit, n_top_feats = 10)

Arguments

fit

Best model fit, such as the output of fitBestModel()

n_top_feats

num Number of top features to plot

Value

Variable importance plot (a ggplot2 object)

Examples

data(demo_fit)
plotTopFeatsVI(demo_fit, n_top_feats = 10)