Generates a plot showing the top features and their variable importance scores.
plotTopFeatsVI(fit, n_top_feats = 10)Best model fit, such as the output of fitBestModel()
num Number of top features to plot
Variable importance plot (a ggplot2 object)
data(demo_fit)
plotTopFeatsVI(demo_fit, n_top_feats = 10)